@@ -1,5 +1,10 @@
 #### CMAKE CONFIGURATION ####
 
+if test -z "$CMAKE_BIN"; then
+  # Look for a cmake3 binary in the current path
+  CMAKE_BIN=`which cmake3 2>/dev/null`
+fi
+
 if test -z "$CMAKE_BIN"; then
   # Look for a cmake binary in the current path
   CMAKE_BIN=`which cmake 2>/dev/null`
@@ -16,11 +21,11 @@ if test -z "$CMAKE_BIN"; then
   echo ""
   echo "CMake was not found on the PATH. Please install CMake:"
   echo ""
-  echo " - yum install cmake          (Fedora/CentOS; inside a terminal)"
-  echo " - apt install cmake          (Debian/Ubuntu; inside a terminal)."
-  echo " - pacman -S cmake            (Arch Linux; inside a terminal)."
-  echo " - brew install cmake         (MacOS; inside a terminal with Homebrew)"
-  echo " - port install cmake         (MacOS; inside a terminal with MacPorts)"
+  echo " - sudo yum install cmake          (Fedora/CentOS; inside a terminal)"
+  echo " - sudo apt install cmake          (Debian/Ubuntu; inside a terminal)."
+  echo " - sudo pacman -S cmake            (Arch Linux; inside a terminal)."
+  echo " - sudo brew install cmake         (MacOS; inside a terminal with Homebrew)"
+  echo " - sudo port install cmake         (MacOS; inside a terminal with MacPorts)"
   echo ""
   echo "Alternatively install CMake from: <https://cmake.org/>"
   echo ""
